@@ -16,14 +16,17 @@ def resize_image_folder(bucket, key_prefix, pil_size):
             continue
         with tempfile.TemporaryFile() as big, tempfile.TemporaryFile() as small:
             # download file and resize
-            key.get_contents_to_file(big)
-            big.flush()
-            big.seek(0)
-            img = Image.open(big)
-            img.thumbnail(pil_size, Image.ANTIALIAS)
+            try:
+                key.get_contents_to_file(big)
+                big.flush()
+                big.seek(0)
+                img = Image.open(big)
+                img.thumbnail(pil_size, Image.ANTIALIAS)
 
-            img.save(small, img.format)
-            small.flush()
-            small.seek(0)
-            key.set_metadata('size', str(pil_size))
-            key.set_contents_from_file(small, headers={'Content-Type': key.content_type})
+                img.save(small, img.format)
+                small.flush()
+                small.seek(0)
+                key.set_metadata('size', str(pil_size))
+                key.set_contents_from_file(small, headers={'Content-Type': key.content_type})
+            except:
+                pass
